@@ -1,15 +1,11 @@
 from __future__ import division
 
-from StringIO import StringIO
-import cPickle
 import numpy as np
 import scipy as sp
 import pandas as pd
 from scipy.stats import gamma
-from sklearn.decomposition import PCA
 import matplotlib.pyplot as plt
-
-import seaborn as sns
+from six.moves import range, StringIO, cPickle
 
 
 class HRFModel(object):
@@ -246,6 +242,7 @@ class DesignMatrix(object):
         confounds = self._validate_component(confounds, "confound")
 
         if confound_pca:
+            from sklearn.decomposition import PCA
             pca = PCA(0.99).fit_transform(confounds)
             n_conf = pca.shape[1]
             new_columns = pd.Series(["confound_%d"] * n_conf) % range(n_conf)
@@ -452,6 +449,7 @@ class DesignMatrix(object):
 
     def plot_confound_correlation(self, fname=None, legend=True):
         """Plot how correlated the condition and confound regressors are."""
+        import seaborn as sns
         corrs = self.design_matrix.corr()
         corrs = corrs.loc[self._confound_names, self._condition_names]
 
@@ -623,7 +621,7 @@ def fsl_highpass_matrix(ntp, cutoff, tr=2):
 
     H = np.zeros((ntp, ntp))
     X = np.column_stack((np.ones(ntp), np.arange(ntp)))
-    for k in xrange(ntp):
+    for k in range(ntp):
         W = np.diag(K[k])
         hat = np.dot(np.dot(X, np.linalg.pinv(np.dot(W, X))), W)
         H[k] = hat[k]
